@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10005 2017-06-03 09:30:38Z David $
+# $Id: __init__.py 10284 2017-09-10 17:17:32Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-06-03 17:30:38 +0800 (Sat, 03 Jun 2017) $
-# $Revision: 10005 $
+# $Date: 2017-09-11 01:17:32 +0800 (Mon, 11 Sep 2017) $
+# $Revision: 10284 $
 """
 Celery tasks which should be run at cloud worker.
 """
@@ -56,7 +56,11 @@ def send(email_messages, fail_silently=False, *args, **kws):
     folderName = finishDateTime.strftime('%Y-%m-%d')
     folderPath = os.path.join('sent', folderName)
     if not os.path.exists(folderPath):
-        os.makedirs(folderPath)
+        try:
+            os.makedirs(folderPath)
+        except Exception as e:
+            logger.error("os.makedirs(folderPath):" + str(e))
+            pass
 
     sesExtra = []
 
