@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 10176 2017-08-13 09:12:03Z David $
+# $Id: AttachSettingsTest.py 10194 2017-08-16 05:53:21Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-08-13 17:12:03 +0800 (Sun, 13 Aug 2017) $
-# $Revision: 10176 $
+# $Date: 2017-08-16 13:53:21 +0800 (Wed, 16 Aug 2017) $
+# $Revision: 10194 $
 
 import os
 
@@ -185,12 +185,6 @@ class TestAttachSettings(TestCase):
         self.assertEqual(settingsContent['ACCOUNT_LOGIN_REDIRECT_URL'], 
                          loginUrlSettings['SOCIAL_AUTH_LOGIN_REDIRECT_URL'])
 
-        self.assertEqual(settingsContent['SECURE_PROXY_SSL_HEADER'],
-                         httpsSettings['SECURE_PROXY_SSL_HEADER'])
-
-        self.assertEqual(settingsContentForHTTP['SECURE_PROXY_SSL_HEADER'],
-                         httpSettings['SECURE_PROXY_SSL_HEADER'])
-
         self.assertEqual(settingsContent['DEFAULT_HTTP_PROTOCOL'],
                          httpsSettings['DEFAULT_HTTP_PROTOCOL'])
 
